@@ -436,7 +436,7 @@ class IpPairing(AbstractPairing):
 
         return True
 
-    async def image(self, accessory, width, height):
+    async def image(self, accessory: int, width: int, height: int) -> bytes:
         await self._ensure_connected()
 
         try:
